const factoryAddress = "0x556f4c3aaa6c6b76e1bba0409d99d4a483b29997";
    const burnLpAddress = "0xAdA0Bfc16c120014458f10BCc14fdcF703A7EEe4";
    let provider, signer;

    document.getElementById('connectWallet').addEventListener('click', async () => {
      if (!window.ethereum) {
        alert("MetaMask is required.");
        return;
      }

      provider = new ethers.providers.Web3Provider(window.ethereum);
      await provider.send("eth_requestAccounts", []);
      signer = provider.getSigner();

      const walletAddress = await signer.getAddress();
      document.getElementById("walletAddress").textContent = `Connected: ${walletAddress}`;
      document.getElementById("connectWallet").disabled = true;

      fetchLpData();
    });

    async function fetchLpData() {
      const table = document.getElementById("lpTable");
      const tbody = table.querySelector("tbody");
      tbody.innerHTML = ""; // Clear existing rows

      try {
        // Step 1: Fetch the number of pairs
        const factoryAbi = ["function allPairsLength() view returns (uint256)", "function allPairs(uint256) view returns (address)"];
        const factoryContract = new ethers.Contract(factoryAddress, factoryAbi, provider);
        
        const allPairsLength = await factoryContract.allPairsLength();
        console.log(`Total pairs: ${allPairsLength}`);

        // Step 2: Loop through each pair and fetch relevant data
        for (let i = 0; i < allPairsLength; i++) {
          const lpAddress = await factoryContract.allPairs(i);
          console.log(`Fetched LP address: ${lpAddress}`);
          
          const pairData = await getLpPairData(lpAddress);

          const row = document.createElement("tr");
          row.innerHTML = `
            <td>${pairData.name}</td>
            <td>${pairData.token0}</td>
            <td>${pairData.token1}</td>
            <td>${pairData.balance}</td>
            <td>
              <button onclick="burnLp('${pairData.token0}', '${pairData.token1}')">Burn</button>
            </td>
          `;
          tbody.appendChild(row);
        }
      } catch (error) {
        console.error("Error fetching LP data:", error);
      }
    }

    async function getLpPairData(lpAddress) {
  try {
    // Get the pair's token addresses and balance
    const abi = [
      "function token0() view returns (address)", 
      "function token1() view returns (address)",
      "function balanceOf(address owner) view returns (uint256)",
      "function symbol() view returns (string)"
    ];
    const lpContract = new ethers.Contract(lpAddress, abi, provider);

    const token0 = await lpContract.token0();
    const token1 = await lpContract.token1();

    // Fetch token symbols for token0 and token1
    const token0Contract = new ethers.Contract(token0, ["function symbol() view returns (string)"], provider);
    const token1Contract = new ethers.Contract(token1, ["function symbol() view returns (string)"], provider);
    const token0Symbol = await token0Contract.symbol();
    const token1Symbol = await token1Contract.symbol();

    const balance = await getLpBalance(lpAddress);

    return { name: `${token0Symbol}/${token1Symbol}`, token0, token1, balance, token0Symbol, token1Symbol };
  } catch (error) {
    console.error(`Error fetching pair data for ${lpAddress}:`, error);
    return { name: "Error", token0: "Error", token1: "Error", balance: "Error" };
  }
}


    async function getLpBalance(lpAddress) {
      try {
        const abi = ["function balanceOf(address owner) view returns (uint256)"];
        const lpContract = new ethers.Contract(lpAddress, abi, provider);
        const balance = await lpContract.balanceOf(burnLpAddress);
        return ethers.utils.formatUnits(balance, 18); // Adjust decimals
      } catch (error) {
        console.error(`Error fetching balance for LP ${lpAddress}:`, error);
        return "Error";
      }
    }

    async function burnLp(token0, token1) {
      try {
        console.log(`Attempting to burn LP for tokens ${token0} and ${token1}`); // Log attempt

        const abi = [
          {
            "inputs": [
              { "internalType": "address[]", "name": "tokens0", "type": "address[]" },
              { "internalType": "address[]", "name": "tokens1", "type": "address[]" }
            ],
            "name": "convertLps",
            "outputs": [],
            "stateMutability": "nonpayable",
            "type": "function"
          }
        ];

        const burnContract = new ethers.Contract(burnLpAddress, abi, signer);
        
        console.log(`Calling convertLps with tokens ${token0}, ${token1}`); // Log contract call

        const tx = await burnContract.convertLps([token0], [token1]);
        console.log(`Transaction sent:`, tx); // Log transaction object
        await tx.wait();
        console.log("Burn transaction confirmed!"); // Log confirmation
        alert("Burn successful!");
        fetchLpData(); // Refresh data after burning
      } catch (error) {
        console.error("Error burning LP tokens:", error);
        alert("Burn failed. Check console for details.");
      }
    }